==> zio-aws-accessanalyzer_2.13-5.17.104.3-sources.jar: zio/aws/accessanalyzer/model/ListAnalyzersRequest.scala <==
package zio.aws.accessanalyzer.model
import zio.aws.accessanalyzer.model.primitives.{Token, Integer}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ListAnalyzersRequest(
    maxResults: Option[Integer] = None,
    nextToken: Option[Token] = None,
    `type`: Option[zio.aws.accessanalyzer.model.Type] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.accessanalyzer.model.ListAnalyzersRequest = {
    import ListAnalyzersRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.accessanalyzer.model.ListAnalyzersRequest
      .builder()
      .optionallyWith(
        maxResults.map(value => Integer.unwrap(value): java.lang.Integer)
      )(_.maxResults)
      .optionallyWith(
        nextToken.map(value => Token.unwrap(value): java.lang.String)
      )(_.nextToken)
      .optionallyWith(`type`.map(value => value.unwrap))(_.`type`)
      .build()
  }
  def asReadOnly: zio.aws.accessanalyzer.model.ListAnalyzersRequest.ReadOnly =
    zio.aws.accessanalyzer.model.ListAnalyzersRequest.wrap(buildAwsValue())
}
object ListAnalyzersRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.accessanalyzer.model.ListAnalyzersRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.accessanalyzer.model.ListAnalyzersRequest =
      zio.aws.accessanalyzer.model.ListAnalyzersRequest(
        maxResults.map(value => value),
        nextToken.map(value => value),
        `type`.map(value => value)
      )
    def maxResults: Option[Integer]
    def nextToken: Option[Token]
    def `type`: Option[zio.aws.accessanalyzer.model.Type]
    def getMaxResults: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("maxResults", maxResults)
    def getNextToken: ZIO[Any, AwsError, Token] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getType: ZIO[Any, AwsError, zio.aws.accessanalyzer.model.Type] =
      AwsError.unwrapOptionField("type", `type`)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.accessanalyzer.model.ListAnalyzersRequest
  ) extends zio.aws.accessanalyzer.model.ListAnalyzersRequest.ReadOnly {
    override val maxResults: Option[Integer] = scala
      .Option(impl.maxResults())
      .map(value => zio.aws.accessanalyzer.model.primitives.Integer(value))
    override val nextToken: Option[Token] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.accessanalyzer.model.primitives.Token(value))
    override val `type`: Option[zio.aws.accessanalyzer.model.Type] = scala
      .Option(impl.`type`())
      .map(value => zio.aws.accessanalyzer.model.Type.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.accessanalyzer.model.ListAnalyzersRequest
  ): zio.aws.accessanalyzer.model.ListAnalyzersRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-accessanalyzer_2.13-5.17.155.2-sources.jar: zio/aws/accessanalyzer/model/ListAnalyzersRequest.scala <==
package zio.aws.accessanalyzer.model
import zio.aws.accessanalyzer.model.primitives.{Token, Integer}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ListAnalyzersRequest(
    maxResults: Option[Integer] = None,
    nextToken: Option[Token] = None,
    `type`: Option[zio.aws.accessanalyzer.model.Type] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.accessanalyzer.model.ListAnalyzersRequest = {
    import ListAnalyzersRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.accessanalyzer.model.ListAnalyzersRequest
      .builder()
      .optionallyWith(maxResults.map(value => value: java.lang.Integer))(
        _.maxResults
      )
      .optionallyWith(
        nextToken.map(value => Token.unwrap(value): java.lang.String)
      )(_.nextToken)
      .optionallyWith(`type`.map(value => value.unwrap))(_.`type`)
      .build()
  }
  def asReadOnly: zio.aws.accessanalyzer.model.ListAnalyzersRequest.ReadOnly =
    zio.aws.accessanalyzer.model.ListAnalyzersRequest.wrap(buildAwsValue())
}
object ListAnalyzersRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.accessanalyzer.model.ListAnalyzersRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.accessanalyzer.model.ListAnalyzersRequest =
      zio.aws.accessanalyzer.model.ListAnalyzersRequest(
        maxResults.map(value => value),
        nextToken.map(value => value),
        `type`.map(value => value)
      )
    def maxResults: Option[Integer]
    def nextToken: Option[Token]
    def `type`: Option[zio.aws.accessanalyzer.model.Type]
    def getMaxResults: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("maxResults", maxResults)
    def getNextToken: ZIO[Any, AwsError, Token] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getType: ZIO[Any, AwsError, zio.aws.accessanalyzer.model.Type] =
      AwsError.unwrapOptionField("type", `type`)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.accessanalyzer.model.ListAnalyzersRequest
  ) extends zio.aws.accessanalyzer.model.ListAnalyzersRequest.ReadOnly {
    override val maxResults: Option[Integer] =
      scala.Option(impl.maxResults()).map(value => value: Integer)
    override val nextToken: Option[Token] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.accessanalyzer.model.primitives.Token(value))
    override val `type`: Option[zio.aws.accessanalyzer.model.Type] = scala
      .Option(impl.`type`())
      .map(value => zio.aws.accessanalyzer.model.Type.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.accessanalyzer.model.ListAnalyzersRequest
  ): zio.aws.accessanalyzer.model.ListAnalyzersRequest.ReadOnly = new Wrapper(
    impl
  )
}
